==> centreon-web-24.04.20.tar.gz: centreon-web-24.04.20/www/front_src/src/Dashboards/SingleInstancePage/Dashboard/Layout/Layout.tsx <==
import { Layout } from 'react-grid-layout';

import { DashboardLayout } from '@centreon/ui';

import { AddWidgetPanel } from '../AddEditWidget';
import { Panel } from '../models';
import useLinkToResourceStatus from '../hooks/useLinkToResourceStatus';

import DashboardPanel from './Panel/Panel';
import PanelHeader from './Panel/PanelHeader';

interface Props {
  canEdit?: boolean;
  changeLayout?: (newLayout: Array<Layout>) => void;
  displayMoreActions?: boolean;
  isEditing?: boolean;
  isStatic: boolean;
  panels: Array<Panel>;
  setRefreshCount?: (id) => void;
}

const PanelsLayout = ({
  isEditing,
  panels,
  isStatic,
  changeLayout,
  canEdit,
  setRefreshCount,
  displayMoreActions = true
}: Props): JSX.Element => {
  const { getLinkToResourceStatusPage, changeViewMode } =
    useLinkToResourceStatus();

  return (
    <DashboardLayout.Layout
      changeLayout={changeLayout}
      displayGrid={isEditing}
      isStatic={isStatic}
      layout={panels}
    >
      {panels.map(
        ({ i, panelConfiguration, refreshCount, data, name, options }) => (
          <DashboardLayout.Item
            canMove={
              canEdit && isEditing && !panelConfiguration?.isAddWidgetPanel
            }
            disablePadding={panelConfiguration?.isAddWidgetPanel}
            header={
              !panelConfiguration?.isAddWidgetPanel ? (
                <PanelHeader
                  changeViewMode={() => changeViewMode(options?.displayType)}
                  displayMoreActions={displayMoreActions}
                  id={i}
                  linkToResourceStatus={
                    data?.resources
                      ? getLinkToResourceStatusPage(data, name, options)
                      : undefined
                  }
                  setRefreshCount={setRefreshCount}
                />
              ) : undefined
            }
            id={i}
            key={i}
          >
            {panelConfiguration?.isAddWidgetPanel ? (
              <AddWidgetPanel />
            ) : (
              <DashboardPanel id={i} refreshCount={refreshCount} />
            )}
          </DashboardLayout.Item>
        )
      )}
    </DashboardLayout.Layout>
  );
};

export default PanelsLayout;

==> centreon-web-24.10.19.tar.gz: centreon-web-24.10.19/www/front_src/src/Dashboards/SingleInstancePage/Dashboard/Layout/Layout.tsx <==
import { isEmpty, isNil, lte } from 'ramda';
import type { Layout } from 'react-grid-layout';

import { DashboardLayout } from '@centreon/ui';

import { AddWidgetPanel } from '../AddEditWidget';
import useLinkToResourceStatus from '../hooks/useLinkToResourceStatus';
import type { Panel } from '../models';

import DashboardPanel from './Panel/Panel';
import PanelHeader from './Panel/PanelHeader';

interface Props {
  canEdit?: boolean;
  changeLayout?: (newLayout: Array<Layout>) => void;
  dashboardId: number | string;
  displayMoreActions?: boolean;
  isEditing?: boolean;
  isStatic: boolean;
  panels: Array<Panel>;
  playlistHash?: string;
  setRefreshCount?: (id) => void;
}

const PanelsLayout = ({
  isEditing,
  panels,
  isStatic,
  changeLayout,
  canEdit,
  setRefreshCount,
  displayMoreActions = true,
  playlistHash,
  dashboardId
}: Props): JSX.Element => {
  const { getLinkToResourceStatusPage, changeViewMode, getPageType } =
    useLinkToResourceStatus();

  return (
    <DashboardLayout.Layout
      additionalMemoProps={[dashboardId]}
      changeLayout={changeLayout}
      displayGrid={isEditing}
      isStatic={isStatic}
      layout={panels}
    >
      {panels.map(
        ({ i, panelConfiguration, refreshCount, data, name, options, w }) => (
          <DashboardLayout.Item
            additionalMemoProps={[dashboardId, panelConfiguration.path]}
            canMove={
              canEdit && isEditing && !panelConfiguration?.isAddWidgetPanel
            }
            disablePadding={panelConfiguration?.isAddWidgetPanel}
            header={
              !panelConfiguration?.isAddWidgetPanel ? (
                <PanelHeader
                  changeViewMode={() => changeViewMode(options?.displayType)}
                  displayMoreActions={displayMoreActions}
                  displayShrinkRefresh={
                    lte(w, 3) &&
                    !isNil(options?.name) &&
                    !isEmpty(options?.name)
                  }
                  forceDisplayShrinkRefresh={
                    lte(w, 2) &&
                    !isNil(options?.name) &&
                    !isEmpty(options?.name)
                  }
                  id={i}
                  linkToResourceStatus={
                    data?.resources
                      ? getLinkToResourceStatusPage(data, name, options)
                      : undefined
                  }
                  pageType={getPageType(data)}
                  setRefreshCount={setRefreshCount}
                  name={name}
                />
              ) : undefined
            }
            id={i}
            key={i}
          >
            {panelConfiguration?.isAddWidgetPanel ? (
              <AddWidgetPanel />
            ) : (
              <DashboardPanel
                dashboardId={dashboardId}
                id={i}
                playlistHash={playlistHash}
                refreshCount={refreshCount}
              />
            )}
          </DashboardLayout.Item>
        )
      )}
    </DashboardLayout.Layout>
  );
};

export default PanelsLayout;
